@@ -71,6 +71,13 @@ Circuit internals
    Circuit.C
    Circuit.X
 
+Circuit reduction
+------------------
+.. autosummary::
+   :toctree: generated/
+
+   reduce_circuit
+
 Graph representation
 --------------------
 .. autosummary::
@@ -91,7 +98,7 @@ import numpy as np
 
 from .constants import INF, S_DEF_DEFAULT, NumberLike
 from .media import media
-from .network import Network, s2s
+from .network import Network, connect, innerconnect, s2s
 from .util import subplots
 
 if TYPE_CHECKING:
@@ -132,7 +139,7 @@ class Circuit:
         except ImportError as err:
             raise ImportError('networkx package as not been installed and is required.') from err
 
-    def __init__(self, connections: list[list[tuple]], name: str = None,) -> None:
+    def __init__(self, connections: list[list[tuple]], name: str = None, auto_reduce: bool = False) -> None:
         """
         Circuit constructor. Creates a circuit made of a set of N-ports networks.
 
@@ -145,6 +152,10 @@ class Circuit:
             Port number indexing starts from zero.
         name : string, optional
             Name assigned to the circuit (Network). Default is None.
+        auto_reduce : bool, optional
+            If True, the circuit will be automatically reduced using :func:`reduce_circuit`.
+            This will change the circuit connections description, affecting inner current and voltage distributions.
+            Suitable for cases where only the S-parameters of the final circuit ports are of interest. Default is False.
 
 
         Examples
@@ -211,9 +222,23 @@ class Circuit:
         self.frequency = ntws[0].frequency
 
         # Check that a (ntwk, port) combination appears only once in the connexion map
-        nodes = [(ntwk.name, port) for (con_idx, (ntwk, port)) in [con for con in self.connections_list]]
+        Circuit.check_duplicate_names(self.connections_list)
+
+        # Reduce the circuit if requested
+        if auto_reduce:
+            self.connections = reduce_circuit(self.connections,
+                                              check_duplication=False,
+                                              split_ground=True)
+
+    @classmethod
+    def check_duplicate_names(cls, connections_list: list):
+        """
+        Check that a (ntwk, port) combination appears only once in the connexion map
+        """
+        nodes = [(ntwk.name, port) for (con_idx, (ntwk, port)) in [con for con in connections_list]]
         if len(nodes) > len(set(nodes)):
-            raise AttributeError('A (network, port) node appears twice in the connection description.')
+            duplicate_nodes = [node for node in nodes if nodes.count(node) > 1]
+            raise AttributeError(f'Nodes {duplicate_nodes} appears twice in the connection description.')
 
 
     def _is_named(self, ntw):
@@ -225,6 +250,20 @@ class Circuit:
         else:
             return True
 
+    @classmethod
+    def _is_port(cls, ntw: Network):
+        """
+        Return True is the network is a port, False otherwise
+        """
+        return ntw._ext_attrs.get("_is_circuit_port", False)
+
+    @classmethod
+    def _is_ground(cls, ntw: Network):
+        """
+        Return True is the network is a ground, False otherwise
+        """
+        return ntw._ext_attrs.get("_is_circuit_ground", False)
+
     @classmethod
     def Port(cls, frequency: Frequency, name: str, z0: float = 50) -> Network:
         """
@@ -257,7 +296,7 @@ class Circuit:
         """
         _media = media.DefinedGammaZ0(frequency, z0=z0)
         port = _media.match(name=name)
-        port._is_circuit_port = True
+        port._ext_attrs['_is_circuit_port'] = True
         return port
 
     @classmethod
@@ -381,7 +420,9 @@ class Circuit:
             In [18]: ground = rf.Circuit.Ground(freq, name='GND')
 
         """
-        return cls.ShuntAdmittance(frequency, Y=INF, name=name)
+        ground = cls.ShuntAdmittance(frequency, Y=INF, name=name)
+        ground._ext_attrs['_is_circuit_ground'] = True
+        return ground
 
     @classmethod
     def Open(cls, frequency: Frequency, name: str, z0: float = 50) -> Network:
@@ -682,7 +723,7 @@ class Circuit:
             Shape `f x (nb_inter*nb_n) x (nb_inter*nb_n)`
         """
         # list all networks which are not considered as "ports",
-        ntws = {k:v for k,v in self.networks_dict().items() if not getattr(v, '_is_circuit_port', False)}
+        ntws = {k:v for k,v in self.networks_dict().items() if not Circuit._is_port(v)}
 
         # generate the port reordering indexes from each connections
         ntws_ports_reordering = {ntw:[] for ntw in ntws}
@@ -719,7 +760,8 @@ class Circuit:
         S : :class:`numpy.ndarray`
             global scattering parameters of the circuit.
         """
-        return self.X @ np.linalg.inv(np.identity(self.dim) - self.C @ self.X)
+        X = self.X
+        return X @ np.linalg.inv(np.identity(self.dim) - self.C @ X)
 
     @property
     def port_indexes(self) -> list:
@@ -733,7 +775,7 @@ class Circuit:
         port_indexes = []
         for (idx_cnx, cnx) in enumerate(chain.from_iterable(self.connections)):
             ntw, ntw_port = cnx
-            if getattr(ntw, '_is_circuit_port', False):
+            if Circuit._is_port(ntw):
                 port_indexes.append(idx_cnx)
         return port_indexes
 
@@ -785,9 +827,50 @@ class Circuit:
             Scattering parameters of the circuit for the external ports.
             Shape `f x nb_ports x nb_ports`
         """
+        # The external S-matrix is the submatrix corresponding to external ports:
+        # port_indexes = self.port_indexes
+        # a, b = np.meshgrid(port_indexes, port_indexes, indexing='ij')
+        # S_ext = self.s[:, a, b]
+
+        # Instead of calculating all S-parameters and taking a submatrix,
+        # the following faster approach only calculates external the S-parameters
+        # from block-matrix operations.
+        # generate index lists of internal and external ports
         port_indexes = self.port_indexes
-        a, b = np.meshgrid(port_indexes, port_indexes, indexing='ij')
-        S_ext = self.s[:, a, b]
+        in_idxs = [(i,) for i in range(self.dim) if i not in port_indexes]
+        ext_idxs = [(i,) for i in port_indexes]
+        ext_l, in_l = len(ext_idxs), len(in_idxs)
+
+        # generate index slices for each sub-matrices
+        idx_a, idx_b, idx_c, idx_d = (
+            np.repeat(i, l, axis=1)
+            for i, l in (
+                (ext_idxs, ext_l),
+                (ext_idxs, in_l),
+                (in_idxs, ext_l),
+                (in_idxs, in_l),
+            )
+        )
+
+        # sub-matrices index, Matrix = [[A, B], [C, D]]]
+        A_idx = (slice(None), idx_a, idx_a.T)
+        B_idx = (slice(None), idx_b, idx_c.T)
+        C_idx = (slice(None), idx_c, idx_b.T)
+        D_idx = (slice(None), idx_d, idx_d.T)
+
+        # Get the buffer of global matrix X, C and intermediate temporary matrix t
+        x, c = self.X, self.C
+        t = np.identity(x.shape[-1]) - c @ x
+
+        # Get the sub-matrices of inverse of intermediate temporary matrix t
+        tmp_mat = np.linalg.inv(t[D_idx]) @ t[C_idx]
+        tA_inv = np.linalg.inv(t[A_idx] - t[B_idx] @ tmp_mat)
+        tC_inv = -tmp_mat @ tA_inv
+
+        # Get the external S-parameters for the external ports
+        # Calculated by multiplying the sub-matrices of x and t
+        S_ext = x[A_idx] @ tA_inv + x[B_idx] @ tC_inv
+
         S_ext = s2s(S_ext, self.port_z0, S_DEF_DEFAULT, 'traveling')
         return S_ext  # shape (nb_frequency, nb_ports, nb_ports)
 
@@ -1315,3 +1398,163 @@ class Circuit:
         # remove x and y axis and labels
         ax.axis('off')
         fig.tight_layout()
+
+## Functions operating on Circuit
+def reduce_circuit(connections: list[list[tuple]],
+                   check_duplication: bool = True,
+                   split_ground: bool = False) -> list[list[tuple]]:
+    """
+    Return a reduced equivalent circuit connections with fewer components.
+
+    The reduced equivalent circuit connections allows faster calculation of the circuit network.
+
+
+    Parameters
+    ----------
+    connections : list.
+            The connection list to reduce.
+    check_duplication : bool, optional.
+            If True, check if the connections have duplicate names. Default is True.
+    split_ground : bool, optional.
+            If True, split the global ground connection to independant ground connections. Default is False.
+
+
+    Returns
+    -------
+    reduced_cnxs : list.
+            The reduced connections.
+
+
+    Examples
+    --------
+    >>> import skrf as rf
+    >>> import numpy as np
+    >>> circuit = rf.Circuit(connections)
+    >>> reduced_cnxs = rf.reduce_circuit(connections)
+    >>> reduced_circuit = rf.Circuit(reduced_cnxs)
+    >>> ntwkA = circuit.network
+    >>> ntwkB = reduced_circuit.network
+    >>> np.allclose(ntwkA.s, ntwkB.s)
+    True
+    """
+
+    def invalide_to_reduce(cnx):
+        return any(Circuit._is_port(ntwk) for ntwk, _ in cnx) or len(cnx) != 2
+
+    if split_ground:
+        tmp_cnxs = []
+        for cnx in connections:
+            ground_ntwk = next((ntwk for ntwk, _ in cnx if Circuit._is_ground(ntwk)), None)
+
+            # If there is no ground network or if the connection has exactly 2 elements, append it as is
+            if not ground_ntwk or len(cnx) == 2:
+                tmp_cnxs.append(cnx)
+                continue
+
+            # Otherwise, create new ground connections
+            for ntwk, port in cnx:
+                if Circuit._is_ground(ntwk):
+                    continue
+                tmp_gnd = Circuit.Ground(frequency=ground_ntwk.frequency,
+                                         name=f'G_{ntwk.name}_{port}',
+                                         z0=ground_ntwk.z0)
+                tmp_cnxs.append([(ntwk, port), (tmp_gnd, 0)])
+
+        connections = tmp_cnxs
+
+    # get the total number of network ports in the specified connection
+    def calculate_ports(cnx: list[tuple[Network, int]]) -> int:
+        if invalide_to_reduce(cnx):
+            return -1
+
+        unique_networks = len(set(ntwk.name for ntwk, _ in cnx))
+        total_ports = sum(ntwk.nports for ntwk, _ in cnx) - 2
+
+        # Return the number of ports if the connections performed
+        return total_ports if unique_networks == 2 else total_ports // 2 - 1
+
+    # List of tuples containing connection indices and their calculated ports
+    cnx_ports_list = [(idx, calculate_ports(cnx)) for idx, cnx in enumerate(connections)]
+    reorder_indices = [idx for idx, _ in sorted(cnx_ports_list, key=lambda x: x[1])]
+
+    # Reorder connections
+    connections = [connections[i] for i in reorder_indices]
+
+    # check if the connections are valid
+    if check_duplication:
+        connections_list = [list(conn) for conn in enumerate(chain.from_iterable(connections))]
+        Circuit.check_duplicate_names(connections_list)
+
+    # Use list comprehension to find the connection need to be reduced
+    gen = (
+        (idx, cnx)
+        for idx, cnx in enumerate(connections)
+        if not invalide_to_reduce(cnx)
+    )
+
+    # Get the first connection need to be reduced
+    skip_idx, cnx_to_reduce = next(gen, (-1, [(Network(), -1)] * 2))
+
+    # If there is no connection need to reduce, return the original circuit
+    if skip_idx == -1:
+        return connections
+
+    # Connect the connections that need to be reduced
+    (ntwkA, k), (ntwkB, l) = cnx_to_reduce
+    ntwks_name = (ntwkA.name, ntwkB.name)
+
+    # Generate the connected network and the original port index
+    ntwk_cnt = Network()
+    if ntwkA.name == ntwkB.name:
+        ntwk_cnt = innerconnect(ntwkA=ntwkA, k=k, l=l)
+    else:
+        ntwk_cnt = connect(ntwkA=ntwkA, k=k, ntwkB=ntwkB, l=l)
+
+    # Generate the port index, the index is the original port index
+    # and the value is the new port index, -1 means the port is removed.
+    port_idx = tuple()
+    if ntwkA.name == ntwkB.name:
+        port_cnt = list(range(ntwk_cnt.nports))
+        port_cnt.insert(min(k, l), -1)
+        port_cnt.insert(max(k, l), -1)
+        port_idx = (tuple(port_cnt), tuple(port_cnt))
+    elif ntwkB.nports == 2 and ntwkA.nports > 2:
+        # if ntwkB is a 2port, then keep port indices where you expect.
+        port_idx = (
+            tuple([(i if i != k else -1) for i in range(ntwkA.nports)]),
+            ((-1, k) if l == 0 else (k, -1)),
+        )
+    else:
+        portA = list(range(ntwkA.nports - 1))
+        portA.insert(k, -1)
+        portB = [i + ntwkA.nports - 1 for i in range(ntwkB.nports - 1)]
+        portB.insert(l, -1)
+
+        port_idx = (tuple(portA), tuple(portB))
+
+    # Perform the reduction to get the reduced circuit connections
+    # Skip the connection that connected and replace the network and port index
+    reduced_cnxs = []
+    for idx, cnx in enumerate(connections):
+        # Skip the connection reduced
+        if idx == skip_idx:
+            continue
+
+        tmp_cnx = []
+        for ntwk, port in cnx:
+            name = ntwk.name
+            ntwk_changed = name in ntwks_name
+
+            ntwk_tmp = ntwk
+            port_tmp = port
+
+            # Update the connected network and port index
+            if ntwk_changed:
+                ntwk_tmp = ntwk_cnt
+                port_tmp = port_idx[ntwks_name.index(name)][port]
+
+            tmp_cnx.append((ntwk_tmp, port_tmp))
+
+        reduced_cnxs.append(tmp_cnx)
+
+    return reduce_circuit(connections=reduced_cnxs, check_duplication=False)
