@@ -65,7 +65,7 @@ from functools import wraps
 from subprocess import PIPE, Popen
 from typing import Any, Callable, Iterable, TypeVar
 
-import numpy as npy
+import numpy as np
 
 from .constants import Number
 
@@ -118,7 +118,7 @@ def copy_doc(copy_func: Callable) -> Callable:
     return wrapper
 
 
-def subplots(*args, **kwargs) -> tuple[Figure, npy.ndarray]:
+def subplots(*args, **kwargs) -> tuple[Figure, np.ndarray]:
     """
     Wraps the matplotlib subplots call and raises if not available.
 
@@ -176,13 +176,13 @@ def now_string_2_dt(s: str) -> datetime:
     return datetime(*[int(k) for k in s.split('.')])
 
 
-def find_nearest(array: npy.ndarray, value: Number) -> Number:
+def find_nearest(array: np.ndarray, value: Number) -> Number:
     """
     Find the nearest value in array.
 
     Parameters
     ----------
-    array :  npy.ndarray
+    array :  np.ndarray
         array we are searching for a value in
     value : element of the array
         value to search for
@@ -197,13 +197,13 @@ def find_nearest(array: npy.ndarray, value: Number) -> Number:
     return array[idx]
 
 
-def find_nearest_index(array: npy.ndarray, value: Number) -> int:
+def find_nearest_index(array: np.ndarray, value: Number) -> int:
     """
     Find the nearest index for a value in array.
 
     Parameters
     ----------
-    array :  npy.ndarray
+    array :  np.ndarray
         array we are searching for a value in
     value : element of the array
         value to search for
@@ -219,10 +219,10 @@ def find_nearest_index(array: npy.ndarray, value: Number) -> int:
     taken from  http://stackoverflow.com/questions/2566412/find-nearest-value-in-numpy-array
 
     """
-    return (npy.abs(array-value)).argmin()
+    return (np.abs(array-value)).argmin()
 
 
-def slice_domain(x: npy.ndarray, domain: tuple):
+def slice_domain(x: np.ndarray, domain: tuple):
     """
     Returns a slice object closest to the `domain` of `x`
 
@@ -230,7 +230,7 @@ def slice_domain(x: npy.ndarray, domain: tuple):
 
     Parameters
     ----------
-    vector : npy.ndarray
+    vector : np.ndarray
         an array of values
     domain : tuple
         tuple of (start,stop) values defining the domain over
@@ -349,7 +349,7 @@ def git_version(modname: str) -> str:
     return out
 
 
-def dict_2_recarray(d: dict, delim: str, dtype: list[tuple]) -> npy.ndarray:
+def dict_2_recarray(d: dict, delim: str, dtype: list[tuple]) -> np.ndarray:
     """
     Turn a dictionary of structured keys to a record array of objects.
 
@@ -394,7 +394,7 @@ def dict_2_recarray(d: dict, delim: str, dtype: list[tuple]) -> npy.ndarray:
     """
 
     split_keys = [tuple(k.split(delim)+[d[k]]) for k in d.keys()]
-    x = npy.array(split_keys, dtype=dtype+[('values',object)])
+    x = np.array(split_keys, dtype=dtype+[('values',object)])
     return x
 
 
@@ -736,7 +736,7 @@ def unique_name(name: str, names: list, exclude: int = -1) -> str:
     return name
 
 
-def smooth(x: npy.ndarray, window_len: int = 11, window: str = 'flat') -> npy.ndarray:
+def smooth(x: np.ndarray, window_len: int = 11, window: str = 'flat') -> np.ndarray:
     """
     Smooth the data using a window with requested size.
 
@@ -797,12 +797,12 @@ def smooth(x: npy.ndarray, window_len: int = 11, window: str = 'flat') -> npy.nd
     if window not in ['flat', 'hanning', 'hamming', 'bartlett', 'blackman']:
         raise ValueError("Window is one of 'flat', 'hanning', 'hamming', 'bartlett', 'blackman'")
 
-    s = npy.r_[x[window_len - 1:0:-1], x, x[-2:-window_len - 1:-1]]
+    s = np.r_[x[window_len - 1:0:-1], x, x[-2:-window_len - 1:-1]]
     if window == 'flat':  # moving average
-        w = npy.ones(window_len, 'd')
+        w = np.ones(window_len, 'd')
     else:
-        w = eval('npy.' + window + '(window_len)')
-    y = npy.convolve(w / w.sum(), s, mode='same')
+        w = eval('np.' + window + '(window_len)')
+    y = np.convolve(w / w.sum(), s, mode='same')
     return y[window_len-1:-(window_len-1)]
 
 
@@ -873,9 +873,9 @@ class ProgressBar:
 
 @contextlib.contextmanager
 def suppress_numpy_warnings(**kw):
-    olderr = npy.seterr(**kw)
+    olderr = np.seterr(**kw)
     yield
-    npy.seterr(**olderr)
+    np.seterr(**olderr)
 
 
 def suppress_warning_decorator(msg):
