@@ -1,8 +1,10 @@
-from . import abcvna
-import numpy as np
-import skrf
 from time import sleep
 
+import numpy as np
+
+import skrf
+
+from . import abcvna
 
 # Communication commands and register addresses are listed in the user manual at
 # https://nanorfe.com/nanovna-v2-user-manual.html
@@ -450,7 +452,8 @@ class NanoVNAv2(abcvna.VNA):
                 col = 0
             else:
                 # problem: column index is ambiguous
-                raise ValueError('Source port index `0` is missing in `ports` with length > 1. Column index is ambiguous.')
+                raise ValueError("Source port index `0` is missing in `ports` with length > 1. "
+                                 "Column index is ambiguous.")
 
         # populate N-port network with s11 and s21
         k = 0
